import * as THREE from './three.module.js'

class Video {
  constructor (selector, width, height) {
    this.renderer = new THREE.WebGLRenderer()
    this.renderer.setSize(width, height)
    this.renderer.setPixelRatio(window.devicePixelRatio)

    const target = document.querySelector(selector)
    target.appendChild(this.renderer.domElement)

    this.camera = new THREE.PerspectiveCamera(
      60,
      width/height,
      0.1, 1000
    )

    this.scene = new THREE.Scene()

    const geometry = new THREE.SphereBufferGeometry(1, 16, 16)
    const material = new THREE.MeshBasicMaterial({ color: 0xccddee })
    const sphere = new THREE.Mesh(geometry, material)
    this.scene.add(sphere)
  }

  render (x, y, z) {
    this.camera.position.x = x
    this.camera.position.y = y
    this.camera.position.z = z

    this.renderer.render(this.scene, this.camera)
  }
}

class Game {
  constructor () {
    this.video = new Video('#game-area', 800, 450)
  }

  mainLoop () {
    window.requestAnimationFrame(this.mainLoop.bind(this))

    this.video.render(0, 0, 3)
  }
}

window.onload = function () {
  const game = new Game()
  game.mainLoop()
}
